@@ -13,6 +13,8 @@ from datetime import datetime, timedelta
 def main():
     parser = argparse.ArgumentParser(
         description='Process some output of Covid-19 data in india.')
+    parser.add_argument('--start', type=str,
+                        help='helps to start a covdata server')
     parser.add_argument('-d', '--date', type=str,
                         help='takes date.For date range use two dates separated by "-"')
     parser.add_argument('-s', '--state', type=str,
@@ -36,7 +38,7 @@ def main():
     parser.add_argument('-f', '--of', type=str,
                         help='process data for selected type', choices=['Total_Confirmed', 'Total_Death',
                                                                         'Total_Recovered'])
-    parser.add_argument('--options', type=str, required=True,
+    parser.add_argument('--options', type=str,
                         help='operations user want to do', choices=['show_data', 'demography',
                                                                     'state_dataset', 'data_by_date',
                                                                     'count_by_date', 'rank', 'cumulative_between_date',
@@ -46,6 +48,7 @@ def main():
     args = parser.parse_args()
     init = initializer(silent=True)
     confirmed = init.show_data(of='Confirmed')
+
     if args.options == 'show_data':
         of = args.of
         if '_' in of:
@@ -379,6 +382,9 @@ def main():
         else:
             print('-f flag should be given')
 
+    elif (args.options == None) & (args.start == 'server'):
+        from .SERVER import server
+
 
 if __name__ == '__main__':
     main()
